@@ -91,7 +91,8 @@ NULL
 #' @export
 `$<-.tbl_df` <- function(x, name, value) {
   tbl_subassign(
-    x, i = NULL, as_string(name), list(value),
+    x,
+    i = NULL, as_string(name), list(value),
     i_arg = NULL, j_arg = name, value_arg = substitute(value)
   )
 }
@@ -335,8 +336,9 @@ fix_oob_positive <- function(i, n, warn = TRUE) {
   oob <- which(i > n)
   if (warn && length(oob) > 0) {
     deprecate_soft("3.0.0", "tibble::`[.tbl_df`(i = 'must lie in [0, rows] if positive,')",
-                   details = "Use `NA_integer_` as row index to obtain a row full of `NA` values.",
-                   env = foreign_caller_env())
+      details = "Use `NA_integer_` as row index to obtain a row full of `NA` values.",
+      env = foreign_caller_env()
+    )
   }
 
   i[oob] <- NA_integer_
@@ -347,8 +349,9 @@ fix_oob_negative <- function(i, n, warn = TRUE) {
   oob <- (i < -n)
   if (warn && any(oob, na.rm = TRUE)) {
     deprecate_soft("3.0.0", "tibble::`[.tbl_df`(i = 'must lie in [-rows, 0] if negative,')",
-                   details = "Use `NA_integer_` as row index to obtain a row full of `NA` values.",
-                   env = foreign_caller_env())
+      details = "Use `NA_integer_` as row index to obtain a row full of `NA` values.",
+      env = foreign_caller_env()
+    )
   }
 
   i <- i[!oob]
@@ -362,7 +365,8 @@ fix_oob_invalid <- function(i, is_na_orig) {
   if (has_length(oob)) {
     deprecate_soft("3.0.0", "tibble::`[.tbl_df`(i = 'must use valid row names')",
       details = "Use `NA_integer_` as row index to obtain a row full of `NA` values.",
-      env = foreign_caller_env())
+      env = foreign_caller_env()
+    )
 
     i[oob] <- NA_integer_
   }
@@ -373,7 +377,8 @@ tbl_subset2 <- function(x, j, j_arg) {
   if (is.matrix(j)) {
     deprecate_soft("3.0.0", "tibble::`[[.tbl_df`(j = 'can\\'t be a matrix",
       details = "Recursive subsetting is deprecated for tibbles.",
-      env = foreign_caller_env())
+      env = foreign_caller_env()
+    )
 
     return(as.matrix(x)[[j]])
   }
@@ -391,7 +396,8 @@ tbl_subset2 <- function(x, j, j_arg) {
     } else if (length(j) == 2L) {
       deprecate_soft("3.0.0", "tibble::`[[.tbl_df`(j = 'can\\'t be a vector of length 2')",
         details = "Recursive subsetting is deprecated for tibbles.",
-        env = foreign_caller_env())
+        env = foreign_caller_env()
+      )
     } else {
       # Side effect: throw error for invalid j
       vectbl_as_col_location2(j, length(x), j_arg = j_arg)
@@ -532,7 +538,7 @@ vectbl_as_new_col_index <- function(j, x, j_arg, names = "", value_arg = NULL) {
       names[new][names[new] == ""] <- paste0("...", j_new)
     }
 
-    names[old] <- names(x)[ j[old] ]
+    names[old] <- names(x)[j[old]]
   } else {
     j <- vectbl_as_col_location(j, length(x), names(x), j_arg = j_arg, assign = TRUE)
 
@@ -549,7 +555,7 @@ vectbl_as_new_col_index <- function(j, x, j_arg, names = "", value_arg = NULL) {
     }
 
     old <- (j <= length(x))
-    names[old] <- names(x)[ j[old] ]
+    names[old] <- names(x)[j[old]]
   }
 
   if (anyDuplicated(j)) {
@@ -594,8 +600,17 @@ numtbl_as_col_location_assign <- function(j, n, j_arg) {
   )
 }
 
-vectbl_as_col_location <- function(j, n, names = NULL, j_arg, assign = FALSE) {
-  subclass_col_index_errors(vec_as_location(j, n, names), j_arg = j_arg, assign = assign)
+vectbl_as_col_location <- function(j,
+                                   n,
+                                   names = NULL,
+                                   j_arg,
+                                   assign = FALSE,
+                                   call = caller_env()) {
+  subclass_col_index_errors(
+    vec_as_location(j, n, names, call = call),
+    j_arg = j_arg,
+    assign = assign
+  )
 }
 
 vectbl_as_col_location2 <- function(j, n, names = NULL, j_arg, assign = FALSE) {
@@ -620,7 +635,7 @@ tbl_subassign_col <- function(x, j, value) {
   new <- which(j > length(x))
   if (has_length(new)) {
     length(x) <- max(j[new])
-    names(x)[ j[new] ] <- names2(j)[new]
+    names(x)[j[new]] <- names2(j)[new]
   }
 
   # Update
@@ -664,7 +679,6 @@ tbl_subassign_row <- function(x, i, value, i_arg, value_arg) {
     for (j in seq_along(x)) {
       x[[j]] <- vectbl_assign(x[[j]], i, recycled_value[[j]])
     },
-
     vctrs_error = function(cnd) {
       # Side effect: check if `value` can be recycled
       vectbl_recycle_rhs_rows(value, length(i), i_arg, value_arg)
@@ -750,7 +764,6 @@ vectbl_recycle_rhs_rows <- function(value, nrow, i_arg, value_arg) {
           value[[j]] <- vec_recycle(value[[j]], nrow)
         }
       },
-
       vctrs_error_recycle_incompatible_size = function(cnd) {
         cnd_signal(error_assign_incompatible_size(nrow, value, j, i_arg, value_arg))
       }
